Style2

Struct Style2 

pub struct Style2 {
    pub slant: Option<Slant>,
    pub weight: Option<u16>,
    pub width: Option<Width>,
    /* private fields */
}
Style properties that can be used when requesting or describing a type face.

Fields

slant: Option<Slant>

See Slant.

weight: Option<u16>

Weight or thickness of the glyphs. Allowed values are integers in the range [1, 1000], but most real-world font families only support some integer multiples of 100: {100, 200, …, 900}. Normal text (WEIGHT_NORMAL) is 400; WEIGHT_BOLD is 700.

See: https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight#Common_weight_name_mapping https://docs.microsoft.com/en-us/typography/opentype/spec/os2#usweightclass

width: Option<Width>

See Width.