TypefaceRequest

Struct TypefaceRequest 

pub struct TypefaceRequest {
    pub query: Option<TypefaceQuery>,
    pub flags: Option<TypefaceRequestFlags>,
    pub cache_miss_policy: Option<CacheMissPolicy>,
    /* private fields */
}
Parameters for requesting a typeface.

Fields

query: Option<TypefaceQuery>

Parameters for looking up a typeface.

flags: Option<TypefaceRequestFlags>

Flags for how to process the request, such as which kinds of substitutions are permitted.

cache_miss_policy: Option<CacheMissPolicy>

Setting for what to do if the requested typeface exists but is not cached, and therefore cannot be served immediately.

If this field is empty, the default policy is [fuchsia.fonts/CacheMissPolicy.BLOCK_UNTIL_DOWNLOADED].

If the client needs an immediate response, it can choose one of the non-blocking policies. In this case, clients can also register to be notified when new fonts have been added to the cache by calling [fuchsia.fonts/Provider.RegisterFontSetEventListener].